summaryrefslogtreecommitdiffstats
path: root/fortran/src/H5_f.c
diff options
context:
space:
mode:
authorScot Breitenfeld <brtnfld@hdfgroup.org>2012-09-05 03:46:58 (GMT)
committerScot Breitenfeld <brtnfld@hdfgroup.org>2012-09-05 03:46:58 (GMT)
commit1c9e159ffe6cf85a5c076f747758dc47eb7a111a (patch)
tree9d6f39eeec727c70644a169980e6d3aa5fa30abb /fortran/src/H5_f.c
parent7740e853f4d39ce7a7a6462a3089aa86abbe5f17 (diff)
downloadhdf5-1c9e159ffe6cf85a5c076f747758dc47eb7a111a.zip
hdf5-1c9e159ffe6cf85a5c076f747758dc47eb7a111a.tar.gz
hdf5-1c9e159ffe6cf85a5c076f747758dc47eb7a111a.tar.bz2
[svn-r22737] Fix for HDF5 HDFFV-8109 H5S_UNLIMITED_F has a wrong type
Tested: jam (gnu)
Diffstat (limited to 'fortran/src/H5_f.c')
-rw-r--r--fortran/src/H5_f.c69
1 files changed, 34 insertions, 35 deletions
diff --git a/fortran/src/H5_f.c b/fortran/src/H5_f.c
index 05b7da0..7b55384 100644
--- a/fortran/src/H5_f.c
+++ b/fortran/src/H5_f.c
@@ -330,20 +330,21 @@ nh5close_types_c( hid_t_f * types, int_f *lentypes,
* PURPOSE
* Initialize Fortran flags
* INPUTS
* h5d_flags - H5D inteface flags
* h5e_flags - H5E inteface flags
* h5e_hid_flags - H5E inteface flags of type hid_t
* h5f_flags - H5F interface flags
* h5fd_flags - H5FD interface flags
* h5fd_hid_flags - H5FD interface flags of type hid_t
* h5g_flags - H5G interface flags
* h5i_flags - H5I interface flags
* h5p_flags - H5P interface flags
* h5p_flags_int - H5P interface flags of type integer
* h5r_flags - H5R interface flags
* h5s_flags - H5S interface flags
* h5t_flags - H5T interface flags
* h5z_flags - H5Z interface flags
* OUTPUTS
* None
* RETURNS
@@ -368,7 +369,7 @@ nh5init_flags_c( int_f *h5d_flags, int_f *h5e_flags, hid_t_f *h5e_hid_flags, int
int_f *h5fd_flags, hid_t_f *h5fd_hid_flags,
int_f *h5g_flags, int_f *h5i_flags, int_f *h5l_flags, int_f *h5o_flags,
hid_t_f *h5p_flags, int_f *h5p_flags_int, int_f *h5r_flags, int_f *h5s_flags,
- int_f *h5t_flags, int_f *h5z_flags, int_f *h5_generic_flags)
+ hsize_t_f *h5s_hsize_flags, int_f *h5t_flags, int_f *h5z_flags, int_f *h5_generic_flags)
/******/
{
int ret_value = -1;
@@ -579,31 +580,29 @@ nh5init_flags_c( int_f *h5d_flags, int_f *h5e_flags, hid_t_f *h5e_hid_flags, int
/*
* H5S flags
*/
-
-
h5s_flags[0] = (int_f)H5S_SCALAR;
h5s_flags[1] = (int_f)H5S_SIMPLE;
h5s_flags[2] = (int_f)H5S_NULL;
h5s_flags[3] = (int_f)H5S_SELECT_SET;
h5s_flags[4] = (int_f)H5S_SELECT_OR;
- h5s_flags[5] = (int_f)H5S_UNLIMITED;
- h5s_flags[6] = (int_f)H5S_ALL;
-
- h5s_flags[7] = (int_f)H5S_SELECT_NOOP;
- h5s_flags[8] = (int_f)H5S_SELECT_AND;
- h5s_flags[9] = (int_f)H5S_SELECT_XOR;
- h5s_flags[10] = (int_f)H5S_SELECT_NOTB;
- h5s_flags[11] = (int_f)H5S_SELECT_NOTA;
- h5s_flags[12] = (int_f)H5S_SELECT_APPEND;
- h5s_flags[13] = (int_f)H5S_SELECT_PREPEND;
- h5s_flags[14] = (int_f)H5S_SELECT_INVALID;
-
-
- h5s_flags[15] = (int_f)H5S_SEL_ERROR;
- h5s_flags[16] = (int_f)H5S_SEL_NONE;
- h5s_flags[17] = (int_f)H5S_SEL_POINTS;
- h5s_flags[18] = (int_f)H5S_SEL_HYPERSLABS;
- h5s_flags[19] = (int_f)H5S_SEL_ALL;
+ h5s_flags[5] = (int_f)H5S_ALL;
+
+ h5s_flags[6] = (int_f)H5S_SELECT_NOOP;
+ h5s_flags[7] = (int_f)H5S_SELECT_AND;
+ h5s_flags[8] = (int_f)H5S_SELECT_XOR;
+ h5s_flags[9] = (int_f)H5S_SELECT_NOTB;
+ h5s_flags[10] = (int_f)H5S_SELECT_NOTA;
+ h5s_flags[11] = (int_f)H5S_SELECT_APPEND;
+ h5s_flags[12] = (int_f)H5S_SELECT_PREPEND;
+ h5s_flags[13] = (int_f)H5S_SELECT_INVALID;
+
+ h5s_flags[14] = (int_f)H5S_SEL_ERROR;
+ h5s_flags[15] = (int_f)H5S_SEL_NONE;
+ h5s_flags[16] = (int_f)H5S_SEL_POINTS;
+ h5s_flags[17] = (int_f)H5S_SEL_HYPERSLABS;
+ h5s_flags[18] = (int_f)H5S_SEL_ALL;
+
+ h5s_hsize_flags[0] = (hsize_t_f)H5S_UNLIMITED;
/*
* H5T flags
@@ -330,20 +330,21 @@ nh5close_types_c( hid_t_f * types, int_f *lentypes,
* Initialize Fortran flags
* INPUTS
- * h5d_flags - H5D inteface flags
- * h5e_flags - H5E inteface flags
- * h5e_hid_flags - H5E inteface flags of type hid_t
- * h5f_flags - H5F interface flags
- * h5fd_flags - H5FD interface flags
- * h5fd_hid_flags - H5FD interface flags of type hid_t
- * h5g_flags - H5G interface flags
- * h5i_flags - H5I interface flags
- * h5p_flags - H5P interface flags
- * h5p_flags_int - H5P interface flags of type integer
- * h5r_flags - H5R interface flags
- * h5s_flags - H5S interface flags
- * h5t_flags - H5T interface flags
- * h5z_flags - H5Z interface flags
+ * h5d_flags - H5D inteface flags
+ * h5e_flags - H5E inteface flags
+ * h5e_hid_flags - H5E inteface flags of type hid_t
+ * h5f_flags - H5F interface flags
+ * h5fd_flags - H5FD interface flags
+ * h5fd_hid_flags - H5FD interface flags of type hid_t
+ * h5g_flags - H5G interface flags
+ * h5i_flags - H5I interface flags
+ * h5p_flags - H5P interface flags
+ * h5p_flags_int - H5P interface flags of type integer
+ * h5r_flags - H5R interface flags
+ * h5s_flags - H5S interface flags
+ * h5s_hsize_flags - H5S interface flags of type hsize_t
+ * h5t_flags - H5T interface flags
+ * h5z_flags - H5Z interface flags
* OUTPUTS
* None